formattools.get_articulation_format_contributions
=================================================

.. autofunction:: abjad.tools.formattools.get_articulation_format_contributions.get_articulation_format_contributions
   :noindex:
